NAME
Perl::Critic::Policy::ValuesAndExpressions::ProhibitFiletest_rwxRWX - Prohibit file access tests.
AFFILIATION
This Policy is stand-alone, and is not part of the core Perl::Critic.
DESCRIPTION
This policy prohibits the file access tests -r, -w, -x, -R, -W, and -X. All these do by default is to check the file's access control bits. Access to a file can succeed or fail for other reasons such as the presence of Access Control Lists (ACLs), a file system being mounted read-only, or an executable being corrupt.
This policy is under the "bugs" theme, with low severity.
CONFIGURATION
This Policy has no configuration options.
SEE ALSO
Perl::Critic::Policy::ValuesAndExpressions::ProhibitFiletest_f
https://blogs.perl.org/users/tom_wyant/2022/06/the-file-access-operators-to-use-or-not-to-use.html
SUPPORT
Support is by the author. Please file bug reports at https://github.com/trwyant/perl-Perl-Critic-Policy-ValuesAndExpressions-ProhibitFiletest_rwxRWX/issues or in electronic mail to the author.
AUTHOR
Thomas R. Wyant, III harryfmudd at comcast dot net.
COPYRIGHT
Copyright 2022, 2026 Thomas R. Wyant, III.
This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.